changeset 1572:44e9c0a264de stable

evolve: improve help for prev, next commands
author Greg Ward <greg@gerg.ca>
date Sat, 07 Nov 2015 13:38:22 -0500
parents 0e8936e7cb89
children 0b4cec85d4ab
files hgext/evolve.py
diffstat 1 files changed, 9 insertions(+), 6 deletions(-) [+]
line wrap: on
line diff
--- a/hgext/evolve.py	Sat Nov 07 13:37:26 2015 -0500
+++ b/hgext/evolve.py	Sat Nov 07 13:38:22 2015 -0500
@@ -2055,7 +2055,9 @@
           ('n', 'dry-run', False, _('do not perform actions, just print what would be done'))],
          '[OPTION]...')
 def cmdprevious(ui, repo, **opts):
-    """update to parent and display summary lines"""
+    """update to parent revision
+
+    Displays the summary line of the destination for clarity."""
     wkctx = repo[None]
     wparents = wkctx.parents()
     dryrunopt = opts['dry_run']
@@ -2106,11 +2108,12 @@
           ('n', 'dry-run', False, _('do not perform actions, just print what would be done'))],
          '[OPTION]...')
 def cmdnext(ui, repo, **opts):
-    """update to next child
-
-    You can use the --evolve flag to get unstable children evolved on demand.
-
-    The summary line of the destination is displayed for clarity"""
+    """update to next child revision
+
+    Use the ``--evolve`` flag to evolve unstable children on demand.
+
+    Displays the summary line of the destination for clarity.
+    """
     wkctx = repo[None]
     wparents = wkctx.parents()
     dryrunopt = opts['dry_run']